@@ -6,6 +6,8 @@ Evaluate the similarity between two sentences.
 
 from nltk.translate.bleu_score import sentence_bleu
 import numpy as np
+import warnings
+warnings.filterwarnings('ignore')
 import tensorflow as tf
 
 __all__ = [
